# Conformational Analysis
[![Downloads](https://pepy.tech/badge/omolab-conf-analysis)](https://pepy.tech/project/omolab-conf-analysis) [![Downloads](https://pepy.tech/badge/omolab-conf-analysis/week)](https://pepy.tech/project/omolab-conf-analysis)
[![Python](https://img.shields.io/pypi/pyversions/omolab-conf-analysis)](https://img.shields.io/pypi/pyversions/omolab-conf-analysis)
[![PyPI Version](https://img.shields.io/pypi/v/omolab-conf-analysis)](https://pypi.org/project/omolab-conf-analysis/)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/erdogant/omolab/blob/master/LICENSE)

Conformational analysis of XYZ-files 

**What this program can do**
1) Read in XYZ-files and calculate distances, angles and dihedrals based of 3D coordinates
2) Incorporation of PCA and Clustering to reduce data dimensions and classify XYZ file conformational families
3) Create folder path and directories containing XYZ-files based on conformational family

## Installation
Run the following to install:

```sh
# PyPi
pip install omolab-conf-analysis
```

## Usage
####In your own python file
```
import ConformationalAnalysis
test1 = ConformationalAnalysis()
```
####In command line (not working yet; soon!)
```
mGenerate_Conf_Analysis
```

## Authors
Created by OMOLAB

Property of Matthew Nwerem, MS and O. Maduka Ogba, PhD   
https://madukaogba.com/
